@@ -17,6 +17,10 @@
     bcnt.tax$SPECIES <- levels(bcnt.tax$SPECIES)[bcnt.tax$SPECIES]
     bcnt.tax <- bcnt.tax[, names0]
 
+    incvec <- bcnt.tax$SPECIES == ""
+    incvec[is.na(incvec)] <- NA
+    bcnt.tax$SPECIES[incvec] <- NA
+
     return(bcnt.tax)
   }
 
